
Process high value business logic flows in a trusted environment
-------

**Description:**

Whenever high value business logic flows are processed in a trusted monitored environment 
it reduces the movability of an attacker and chances of succeeding to 
perform successful attacks. If an attacker should breach your application his actions 
could be rapidly followed and counter measures could be taken.


**Solution:**

Verify the application processes or verifies all high value business logic flows in a 
trusted environment, such as on a protected and monitored server.

	